<?php

include_once('apaczkaSoapClient.php');
include_once(realpath(dirname(__FILE__)).'./../functions.inc.php');

class Apaczka_ApaczkaModule_Model_Carrier
		extends Mage_Shipping_Model_Carrier_Abstract
		implements Mage_Shipping_Model_Carrier_Interface
{
	protected $_code = 'apaczka';

	public function collectRates(Mage_Shipping_Model_Rate_Request $request)
	{
		$result = Mage::getModel('shipping/rate_result');
		/* @var $result Mage_Shipping_Model_Rate_Result */
		
		$result = $this->appends($result);
		return $result;
	}

	public function appends(Mage_Shipping_Model_Rate_Result $result){

		$methods = explode(',', $this->getConfigData('allowed_methods'));
		foreach($methods as $met){
			$rate = Mage::getModel('shipping/rate_result_method');
			/* @var $rate Mage_Shipping_Model_Rate_Result_Method */
			$rate->setCarrier($this->_code);
			$rate->setCarrierTitle($this->getConfigData('title'));
			$rate->setMethod($met);
			$rate->setMethodTitle(getCode('method')["$met"]);
			$rate->setPrice($this->getConfigData($met));
			$rate->setCost(0);

			$result->append($rate);
		}

		return $result;
	}
	
	public function getAllowedMethods()
	{	
		return array(
			'DHLSTD' => 'DHL Standard',
		);
		return array(
			'KEX_EXPRESS' => 'KEX Express',
		);
		return array(
			'UPS_K_STANDARD' => 'UPS Standard Krajowy',
		);
		return array(
			'DHLSTD_pob' => 'DHL Standard POBRANIE',
		);
		return array(
			'KEX_EXPRESS_pob' => 'KEX Express POBRANIE',
		);
		return array(
			'UPS_K_STANDARD_pob' => 'UPS Standard Krajowy POBRANIE',
		);
	}

	/**
	 * Do shipment request to carrier web service, obtain Print Shipping Labels and process errors in response
	 *
	 * @param Varien_Object $request
	 * @return Varien_Object
	 */

	public function requestToShipment(Mage_Shipping_Model_Shipment_Request $request)
	{
		$resp = false;
		$isError = false;
		$error_msg = '';
		$pickup_msg = '';
		$apaczkaOrder = null;
		$isOk = false;
		$nstd_string = "";

		$login = $this->getConfigData('login');
		$password = $this->getConfigData('password');
		$apikey = $this->getConfigData('apikey');		
	
		$apaczka = new apaczkaApi($login,$password,$apikey);
		
		$serv = $this->getConfigData('url');
		if($serv == 'PROD'){
			$apaczka->setProductionMode();
		}
		elseif($serv == 'TEST'){
			$apaczka->setTestMode();
		}

		$apaczka->setVerboseMode();

		try {		
			$apaczkaOrder = $this->formShipmentRequest($request);
		} catch (Exception $e) {
			$error_msg = $e->getMessage();
			$isError = true;
		}

		$packages = $request->getPackages();

		//ogarniecie pickupu
		$pickup = $this->getConfigData('pickup');
		if($pickup == 'COURIER' && isset($apaczkaOrder) ){		
			try {	 		
				$pickup_string = explode ( "." ,$packages['1']['params']['customs_value'] );
				if(strlen($pickup_string[0]) >= 9){	
					$pickup_date_time = $this->parsePickupDate($pickup_string[0]);
					$pickup_msg = '<br><br><font color="black">'.$this->displayPickupTime($apaczkaOrder, $pickup_date_time).'</font>';
				}
				else{
					$pickup_msg = '<br><br><font color="black">'.$this->displayPickupTime($apaczkaOrder).'</font>';
				}
				if ($apaczkaOrder->pickupTimeFrom == '' || $apaczkaOrder->pickupDate == ''){
					throw new Exception('Ustaw datę i godzin pickup\'u');
				}
			} catch (Exception $e) {
				$error_msg = $e->getMessage();
				$isError = true;
			}
		}
		//ogarniecie ubezpieczenia
		$tab_custom = explode( "." ,$packages['1']['params']['customs_value'] );
		if( isset($tab_custom[1]) && $tab_custom[1] > 0){
			$kwota = $tab_custom[1];
			$kwota = strrev($kwota);
			$pickup_msg = $pickup_msg.'<br><br><font color="black">'.$this->displayUbez($kwota).'</font>';
		}
		else{
			$pickup_msg = $pickup_msg.'<br><br><font color="black">'.$this->displayUbez(0).'</font>';
		}

		//ogarniecie niestandardu
		$nstd_string = substr($packages['1']['params']['customs_value'], 0, 1);
		if($nstd_string == "-"){
			$pickup_msg = $pickup_msg.'<br><br><font color="black">'.$this->displayNstd(1).'</font>';
		}
		else{
			$pickup_msg = $pickup_msg.'<br><br><font color="black">'.$this->displayNstd(0).'</font>';
		}		


		if(!$isError &&  Mage::getSingleton('core/session')->getPickUp()){
			try {	
				//$str_resp = 'O:8:"stdClass":1:{s:6:"return";O:8:"stdClass":2:{s:5:"order";O:8:"stdClass":21:{s:13:"accountNumber";N;s:9:"codAmount";N;s:8:"contents";s:15:"Wazne dokumenty";s:2:"id";i:330902291;s:10:"isDomestic";b:1;s:9:"netAmount";i:1618;s:21:"notificationDelivered";O:8:"stdClass":4:{s:15:"isReceiverEmail";b:0;s:13:"isReceiverSms";b:0;s:13:"isSenderEmail";b:0;s:11:"isSenderSms";b:0;}s:21:"notificationException";O:8:"stdClass":4:{s:15:"isReceiverEmail";b:0;s:13:"isReceiverSms";b:0;s:13:"isSenderEmail";b:0;s:11:"isSenderSms";b:0;}s:15:"notificationNew";O:8:"stdClass":4:{s:15:"isReceiverEmail";b:0;s:13:"isReceiverSms";b:0;s:13:"isSenderEmail";b:0;s:11:"isSenderSms";b:0;}s:16:"notificationSent";O:8:"stdClass":4:{s:15:"isReceiverEmail";b:0;s:13:"isReceiverSms";b:0;s:13:"isSenderEmail";b:0;s:11:"isSenderSms";b:0;}s:7:"options";O:8:"stdClass":0:{}s:11:"orderNumber";s:11:"13940201926";s:15:"orderPickupType";s:4:"SELF";s:14:"pickupTimeFrom";N;s:12:"pickupTimeTo";N;s:8:"receiver";O:8:"stdClass":10:{s:12:"addressLine1";s:8:"polna 12";s:12:"addressLine2";s:1:".";s:4:"city";s:8:"Warszawa";s:11:"contactName";s:12:"Bolek Bolus1";s:9:"countryId";i:0;s:5:"email";s:17:"sklep@,magento.pl";s:4:"name";s:12:"Bolek Bolu12";s:5:"phone";s:9:"501123123";s:10:"postalCode";s:6:"00-401";s:9:"stateCode";N;}s:15:"referenceNumber";s:10:"MojeID=997";s:6:"sender";O:8:"stdClass":10:{s:12:"addressLine1";s:9:"Leszka 23";s:12:"addressLine2";s:1:".";s:4:"city";s:8:"Warszawa";s:11:"contactName";s:4:"SHOP";s:9:"countryId";i:0;s:5:"email";s:14:"bolek@bolus.pl";s:4:"name";s:7:"Kamil P";s:5:"phone";s:9:"501123123";s:10:"postalCode";s:6:"00-401";s:9:"stateCode";N;}s:11:"serviceCode";s:6:"DHLSTD";s:9:"shipments";O:8:"stdClass":1:{s:8:"Shipment";O:8:"stdClass":8:{s:10:"dimension1";i:45;s:10:"dimension2";i:45;s:10:"dimension3";i:45;s:7:"options";O:8:"stdClass":0:{}s:8:"position";i:0;s:16:"shipmentTypeCode";s:4:"PACZ";s:13:"shipmentValue";N;s:6:"weight";s:1:"6";}}s:13:"waybillNumber";N;}s:6:"result";O:8:"stdClass":1:{s:8:"messages";O:8:"stdClass":0:{}}}}';
				//$resp = unserialize($str_resp);
				$resp = $apaczka->placeOrder($apaczkaOrder);
			} catch (Exception $e) {
				$error_msg = $e->getMessage();
				$isError = true;
			}
		}

		$result = new Varien_Object();

		if(!$isError && isset($resp->return->order) && $resp->return->order && $resp->return->order->id){
			$trackingNumber = $resp->return->order->orderNumber;
			$id = $resp->return->order->id;
			$this->apaczka_id = $id;
			$shippingLabelContent = $apaczka->getWaybillDocument(floor($id))->return->waybillDocument;
			$isOk = true;
		}
		elseif (!$isError && isset($resp->return->result->messages->Message)){
			$error_msg = $resp->return->result->messages->Message->severity.'<br>'.$resp->return->result->messages->Message->description;
			$isError = true;		
		}
		elseif(!$isError && Mage::getSingleton('core/session')->getPickUp()){
			$error_msg = 'Nieznany błąd!';
			$isError = true;
		}
		elseif(!$isError){
			$isError = true;
		}

		$error_msg = $error_msg.$pickup_msg;

		if(!$isOk){		
			$result->setErrors($error_msg);
			$response = new Varien_Object();
			Mage::getSingleton('core/session')->setPickUp(true);
		}
		else{
			Mage::getSingleton('core/session')->setPickUp(false);
		}

		if (!$isError){
			$result->setShippingLabelContent($shippingLabelContent);
			$result->setTrackingNumber($trackingNumber);
			$data[] = array(
				'tracking_number' => $result->getTrackingNumber(),
				'label_content'   => $result->getShippingLabelContent()
			);
			$response = new Varien_Object(array(
				'info'   => $data
			));
		}
		if ($result->getErrors()) {
			$response->setErrors($error_msg);
		}
		return $response;
	}

	protected function formShipmentRequest(Mage_Shipping_Model_Shipment_Request $request)
	{
		$order_id = $request->getOrderShipment()->getOrderId(); //use your own order id 
		$m_order = Mage::getModel("sales/order")->load($order_id); //load order by order id -> Mage_Sales_Model_Order Object
	
		$order = new ApaczkaOrder();

		$order->notificationDelivered = $order->createNotification(false, false, false, false);
		$order->notificationException = $order->createNotification(false, false, false, false);
		$order->notificationNew = $order->createNotification(false, false, false, false);
		$order->notificationSent = $order->createNotification(false, false, false, false);

		$method = $request->getShippingMethod();
		if(substr($method,-3) == 'pob'){
			$czy_pobranie = true;
			$method = substr($method,0,-4);
		}
		else{
			$czy_pobranie = false;
		}

		$referenceNumber = $m_order->getIncrementId();
		$order->referenceNumber = $referenceNumber;

		$order->isDomestic = true;

		//co przewozi
		$packages = $request->getPackages();
		$keys = array_keys($packages['1']['items']);
		$name = $packages['1']['items'][$keys[0]]['name'];
		$order->contents = $name;

		//set...Address($name = 'stefan', $contactName = '.', $addressLine1 = '', $addressLine2 = '', $city = '', $countryId = '', $postalCode = '', $stateCode = '', $email = '', $phone = '');

		$order->setSenderAddress($request->getShipperContactCompanyName(), $this->getConfigData('contact'), $request->getShipperAddressStreet1(), 
			$request->getShipperAddressStreet2(), $request->getShipperAddressCity(), '0', $request->getShipperAddressPostalCode(), '', $this->getConfigData('contact_mail'), $this->getConfigData('contact_phone'));

		$order->setReceiverAddress($request->getRecipientContactPersonFirstName().' '.$request->getRecipientContactPersonLastName(), $request->getRecipientContactPersonFirstName().' '.$request->getRecipientContactPersonLastName(), $request->getRecipientAddressStreet1(), 
			$request->getRecipientAddressStreet2(), $request->getRecipientAddressCity(), '0', $request->getRecipientAddressPostalCode(), '', $m_order->getCustomerEmail(), $request->getRecipientContactPhoneNumber());

		$ammount = floor($m_order->getBaseGrandTotal()*100);
		if($czy_pobranie){
			$account_num  = $this->getConfigData('account_num');
			$order->setPobranie($account_num,$ammount);
		}

		//ustawienia pickupa
		$pickup_type = $this->getConfigData('pickup');
		$time_from = ''; $time_to = ''; $date = ''; $nstd= 0;
		if($pickup_type = 'COURIER'){
			$pickup_string = explode ( "." ,$packages['1']['params']['customs_value'] );
			if(strlen($pickup_string[0]) >= 9){			
				list($date, $time_from) = $this->parsePickupDate($pickup_string[0]);
			}
			
			$time_to = $this->timeAdd($time_from,3);
			if(substr($method,0,3) == 'KEX'){
				$time_from = '08:00';
				$time_to = '16:00';
			}
		}
		$order->setPickup($pickup_type, $time_from, $time_to, $date);

		//lepienie paczek
		$packages = $request->getPackages();
		foreach($packages as $package){
			$container = $package['params']['container'];
			$weight = $package['params']['weight'];
			$length = $package['params']['length'];
			$width = $package['params']['width'];
			$height = $package['params']['height'];

			//typ paczki
			if($container == 'LIST' && $method == 'UPS_K_STANDARD'){
				$order->setServiceCode('UPS_K_EX_SAV');
			}elseif($container == 'PALETA' && $length == 120 && $width == 80){
				$length = 80;
				$width = 120;	
				$order->setServiceCode($method);
			}else{
				$order->setServiceCode($method);
			}

			$order_shipment = new ApaczkaOrderShipment($container, $height, $width, $length, $weight);

			
			//ustawienie ubezpieczenia
			$tab_custom = explode( "." ,$packages['1']['params']['customs_value'] );
			if(isset($tab_custom[1])){
				$kwota = $tab_custom[1];
				$kwota = strrev($kwota);
				$kwota = $kwota*100;
				if($kwota > 0){
					$order_shipment->setShipmentValue($kwota);
				}
			}

			//niestandard zaznaczony
			$nstd_string = substr($packages['1']['params']['customs_value'], 0, 1);
			if($nstd_string == "-"){
				$order_shipment->addOrderOption('PRZES_NIETYP');
			}

			//ograniczenia dhl
			if( (substr($method,0,3) == 'DHL')  &&	($container == 'PACZ') ) {
				if( ($height + $width + $length) > 300 || max($height, $width, $length) > 200 ){
					throw new Exception('Nieprawidłowe wymiary przesyłki! Suma boków musi być mniejsza od 300 cm, a najdłuższy bok mniejszy od 200 cm.');
				}

				if( ($weight > 40) ){
					throw new Exception('Waga przesyłki zbyt duża. Maksymalna waga wynosi 40 kg.');
				}
			
				$wymiary = array($height, $width, $length);
				$max =  max($wymiary);
				foreach($wymiary as $key=>$wymiar){
					if($wymiar == $max){
						unset($wymiary[$key]);
						break;
					}
				}

				if($max > 140 || max($wymiary) > 60 ){
					$order_shipment->addOrderOption('PRZES_NIETYP');
				}

			}
				
			//niestadard i duza paczka ups
			if( substr($method,0,3) == 'UPS' && $container == 'PACZ'){
				$wymiary = array($height, $width, $length);
				$suma = ''; //suma max
				$max =  max($wymiary);
				$suma = $max;
				foreach($wymiary as $key=>$wymiar){
					if($wymiar == $max){
						unset($wymiary[$key]);
						break;
					}
				}
				foreach($wymiary as $wymiar){
					$suma = $suma + ($wymiar * 2);
				}

				if( ($suma > 330) && ($suma <= 419) ){
					$order_shipment->addOrderOption('DUZA_PACZKA');
				}

				if($max > 270){
					throw new Exception('Za duża maksymalna krawędź paczki!');
				}

				if($weight > 70){
					throw new Exception('Za duża waga paczki! Waga nie może przekraczać 70 kg.');
				}

				elseif( ( ($suma > 300) && ($suma <= 330) ) || ( ($weight > 32) && ($weight <= 70) ) || $max > 120 || array_values($wymiary)[0] > 80 ||  array_values($wymiary)[1] > 80 ){
					$order_shipment->addOrderOption('PRZES_NIETYP');
				}			
				
			}

			//kex
			if(	(substr($method,0,3) == 'KEX') && ($container == 'PACZ')	){

				$wymiary = array($height, $width, $length);
				$suma = array_sum($wymiary);
				$max =  max($wymiary);

				if($weight > 30){
					throw new Exception('Za duża waga paczki! Waga nie może przekraczać 30 kg.');
				}
				elseif( $suma > 260 ){
					throw new Exception('Za duże wymiary paczki! Suma wymiarów musi być mniejsza od 260 cm.');
				}
				elseif( $max > 160 ){
					throw new Exception('Za duże wymiary paczki! Długość najdłuższego boku może wyności maksymalnie 160 cm.');
				}
			
				foreach($wymiary as $key=>$wymiar){
					if($wymiar == $max){
						unset($wymiary[$key]);
						break;
					}
				}
				if( array_values($wymiary)[0] > 80 ||  array_values($wymiary)[1] > 80){
					throw new Exception('Za duże wymiary paczki! Szerokość i wysokość może wynosić maksymalnie 80 cm.');
				}
			}
		
			$order->addShipment($order_shipment);
			
		}

		return $order;
	}

	private function parsePickupDate($customs_value){

		//$customs_value = $packages['1']['params']['customs_value'];
		$nstd = 0;
		if($customs_value < 0){
			$customs_value = substr($customs_value,1);
			$nstd = 1;
		}
	 	
		if(strlen($customs_value) == 11){
			$time_from = '0'.substr($customs_value,0,1).':'.substr($customs_value,1,2);
			$time_to = '';

			$date = substr($customs_value,3,4).'-'.substr($customs_value,7,2).'-'.substr($customs_value,9,2);
		}
		elseif(strlen($customs_value) == 12){
			$time_from = substr($customs_value,0,2).':'.substr($customs_value,2,2);
			$time_to = '';
			$date = substr($customs_value,4,4).'-'.substr($customs_value,8,2).'-'.substr($customs_value,10,2);
		}
		else{
			return array();
		}
		
		return array($date, $time_from);

	}


	/**
	 * Return container types of carrier
	 *
	 * @param Varien_Object|null $params
	 * @return array|bool
	 */

	public function getContainerTypes(Varien_Object $params = null)
	{
		return getCode('typy');
	}


	public function isTrackingAvailable()
	{
		return false;
	}

	public function isShippingLabelsAvailable()
	{
		return true;
	}

    	public function isCityRequired()
    	{
        	return true;
    	}
	
	public function getDatesFromApaczka(){
		//$json = '{"daty":[{"data":"2014-08-26","services":[{"service":"DHL","timefrom":"09:00","timeto":"19:00"},{"service":"KEX","timefrom":"10:00","timeto":"20:00"},{"service":"UPS","timefrom":"07:00","timeto":"15:00"}]},{"data":"2014-08-27","services":[{"service":"DHL","timefrom":"09:00","timeto":"19:00"},{"service":"UPS","timefrom":"05:00","timeto":"16:00"}]},{"data":"2014-08-28","services":[{"service":"DHL","timefrom":"09:00","timeto":"19:00"},{"service":"UPS","timefrom":"08:00","timeto":"21:00"}]}]}';		
		try{	
			$json = file_get_contents($this->getConfigData('json'));
		}
		catch(Exception $e){
			throw new Exception('Problem z Api do pobierania godzin pickup\'u. Nie udało się pobrać dat i godzin pickup\'u');
		}
		$dataaa = json_decode($json);
		if(!isset($dataaa->daty)){
			throw new Exception('Problem z Api do pobierania godzin pickup\'u. Nie udało się pobrać dat i godzin pickup\'u');
		}
		return $dataaa;
	}

	public function displayPickupTime($apaczkaOrder, $default_date_time = ''){
			$pickup_date = '';
			$pickup_time_from = '';
			$pickup_time_to = '';

			$label = '';

			if($default_date_time != '' && !empty($default_date_time)){
				$pickup_date = $default_date_time[0];
				$pickup_time_from = $default_date_time[1];
				$pickup_time_to = intval(substr($pickup_time_from,0,strlen($pickup_time_from)-2)) + 3;
				$pickup_time_to = $pickup_time_to.':'.substr($pickup_time_from, -2);
			}

			$dataaa = $this->getDatesFromApaczka();

			$order =  $apaczkaOrder->getOrder();
			$serviceCode = $order['serviceCode'];
			$supplier = substr($serviceCode,0,3);

			foreach($dataaa->daty as $data){
				foreach($data->services as $service){
					if($service->service == $supplier){
						if(!isset($days[$data->data])) {
							$days[$data->data] = array('data'=> $data->data);
						}
						$days[$data->data]['timefrom'] = $service->timefrom;
						$days[$data->data]['timeto'] = $service->timeto;
					}
				}
			}

			//data
			$html = '';
			foreach($days as $day){	
				$selected = ($day['data'] == $pickup_date) ? 'selected' : '';

				$html = $html.'<option value="'.$day['data'].'" '.$selected.'>'.$day['data'].'</option>';
			}

			$html = '<select onchange="showMeTimeFor(this.value)" id="custom_pickup_date" name="container_data">
				'.$html.'
				</select>';

			//czas from
			$div_from = '';
			$first = true;
			foreach($days as $day){	
				if($first && $pickup_date==''){
					$div_from = $div_from.'<div id="timeFor'.$day['data'].'"  style="display: block;"> Czas od: ';
					$pickup_time_to = $this->timeAdd($day['timefrom'],3) ;
					$first = false;		
				}
				elseif($pickup_date!=''){
					if($day['data'] == $pickup_date){
						$div_from = $div_from.'<div id="timeFor'.$day['data'].'"  style="display: block;"> Czas od: ';
						$first = false;	
					}	
					else{
						$div_from = $div_from.'<div id="timeFor'.$day['data'].'"  style="display: none;"> Czas od: ';	
					}
				}
				else{
					$div_from = $div_from.'<div id="timeFor'.$day['data'].'"  style="display: none;"> Czas od: ';
				}
				
				$html_time = '<select id = "timeFromSelect'.$day['data'].'" name="'.$day['data'].'"  onchange="showMeTimeFor(this.name)">';

				$i = $day['timefrom'];
				$do = $day['timeto'];
				$do = $this->timeAdd($do);
				
				while($i != $this->timeAdd($do,-4)){
					$selected = ($i == $pickup_time_from) ? ' selected' : '';	
					$html_time = $html_time.'<option value="'.$i.'"'.$selected.' >'.$i.'</option>';
					$i = $this->timeAdd($i);
				}
				$html_time = $html_time.'</select>';	
				$div_from = $div_from.$html_time;
				$div_from = $div_from.'</div>';
				$html_time = '';	
			}

			//czas to
			$div_to = '';
			$first = true;
			foreach($days as $day){	
				if($first){
					//$div_to = $div_to.'<div id="timeTo'.$day['data'].'"  style="display: block;"> Czas do: ';
					$div_to = $div_to.'<div id="timeTo'.$day['data'].'"  style="display: none;"> Czas do: ';
					$first = false;		
				}
				else{
					$div_to = $div_to.'<div id="timeTo'.$day['data'].'"  style="display: none;"> Czas do: ';
				}
				
				$html_time = '<select id = "timeToSelect'.$day['data'].'"  name="'.$day['data'].'"  onchange="showMeTimeFor(this.name)">';

				$i = $day['timefrom'];
				$do = $day['timeto'];
				
				while($i != $this->timeAdd($do)){	
					$selected = ($i == $pickup_time_to) ? 'selected' : '';		
					$html_time = $html_time.'<option value="'.$i.'" '.$selected.' >'.$i.'</option>';
					$i = $this->timeAdd($i);
				}
				$html_time = $html_time.'</select>';	
				$div_to = $div_to.$html_time;
				$div_to = $div_to.'</div>';
				$html_time = '';	
			}

			//script
			$script = "";
			foreach($days as $day){	
				$script = $script.'document.getElementById("timeFor'.$day['data'].'").style.display="none";
				';
				$script = $script.'document.getElementById("timeTo'.$day['data'].'").style.display="none";
				';			
			}

			$script = $script.'var myDiv = document.getElementById(\'timeFor\'+divToShowId);
					myDiv.style.display=\'block\';
				';
			/*$script = $script.'var myDiv = document.getElementById(\'timeTo\'+divToShowId);
					myDiv.style.display=\'block\';
				';//*/
			
			$red = '<font color="red">'; $red_end = '</font>';
			$script = 'showMeTimeFor = function showMeTimeFor(divToShowId){
				'.$script.'

				var t_elements = document.getElementsByName(\'package_customs_value\');
				for(i = 0; i<t_elements.length; i++){
					var element = t_elements[i];
				
					var date = document.getElementById("custom_pickup_date").value;

					var selectsFrom = document.getElementById(\'timeFromSelect\'+divToShowId);
					var timeFrom = selectsFrom.options[selectsFrom.selectedIndex].value;
					var selectsTo = document.getElementById(\'timeToSelect\'+divToShowId);
					var timeTo = selectsTo.options[selectsTo.selectedIndex].value;
					
					var nstd = "";
					var czy_nstd = (element.value).substring(0,1);
					if(czy_nstd == "-"){
						nstd = "-";
					}

					var pakiet = nstd + timeFrom.substring(0,2) + timeFrom.substring(3,5) 
						+ date.substring(0,4) + date.substring(5,7) + date.substring(8,10);


					var pole = element.value;
					var pole = pole.split(".");

					if(pole[1] != null){
						var kwota = pole[1];
					}
					else{
						var kwota = 0;
					}

					var t_to_element = [timeFrom, timeTo, date];
					element.value = pakiet +"." +kwota;
					element.style.display = "none";
				}
				var od = timeFrom.substring(0,2);
				od = parseInt(od) + 3;
				document.getElementById("od_do").innerHTML = "Do godziny: "+od +":"  +timeFrom.substring(3,5);

				var t_elements = document.getElementsByClassName("customs-value-currency");

				for(i = 0; i < t_elements.length; i++){
					t_elements[i].style.display = "none";
				}
				} ';	

			$script_tmp = "eval(window.atob('".base64_encode($script)."')); showMeTimeFor(this.value)";
			$script_tmp2 = "eval(window.atob('".base64_encode($script)."')); showMeTimeFor(this.name)";		
			$html = str_replace('showMeTimeFor(this.value)', $script_tmp, $html);				
			$div_from = str_replace('showMeTimeFor(this.name)', $script_tmp2, $div_from);			
			$div_to = str_replace('showMeTimeFor(this.name)', $script_tmp2, $div_to);

			$label = '<label id="od_do">Do godziny: '.$pickup_time_to.'</label>';

			if($supplier == "KEX"){	
				return $error_msg = 'Wybierz datę i czas zamówienia odbioru przesyłki:<br>Data: '.$html.'<div style="display: none;">'.$div_from.$div_to.$label.'</div>';
			}
			else{
				return $error_msg = 'Wybierz datę i czas zamówienia odbioru przesyłki:<br>Data: '.$html.$div_from.$div_to.$label;
			}

			

			//return $error_msg = 'Wybierz datę i czas zamówienia odbioru przesyłki:<br>Data: '.$html.$div_from.$div_to.$label;
	}

	public function displayUbez($kwota){

		$ubezp_fun = 	'add_ubezp = function add_ubezp(){
					function reverse(s){
    						return s.split("").reverse().join("");
					}

					var t_elements = document.getElementsByName(\'package_customs_value\');
					for(i = 0; i<t_elements.length; i++){
						var element = t_elements[i];

						/*var selectsFrom = document.getElementById(\'timeFromSelect\'+divToShowId);
						var timeFrom = selectsFrom.options[selectsFrom.selectedIndex].value;
						var selectsTo = document.getElementById(\'timeToSelect\'+divToShowId);
						var timeTo = selectsTo.options[selectsTo.selectedIndex].value;

						var pakiet = timeFrom.substring(0,2) + timeFrom.substring(3,5) + timeTo.substring(0,2) + timeTo.substring(3,5) 
							+ date.substring(0,4) + date.substring(5,7) + date.substring(8,10);*/

						var pole = element.value;
						var pole = pole.split(".");
						var liczba = pole[0];

						var ubezpieczenie = document.getElementsByName("ubezpieczenie");
						var kwota = ubezpieczenie[0].value;
						kwota = reverse(kwota);
					
						element.value = liczba +"." +kwota;
						element.style.display = "none";
					}
				}';
		$ubezp_fun = "eval(window.atob('".base64_encode($ubezp_fun)."')); add_ubezp()";
		$ubezpieczenie = 'Kwota ubezpieczenia (max 9999zł): <input type="number" name="ubezpieczenie" style="width: 60px; text-align: right;" onchange="'.$ubezp_fun.'" value="'.$kwota.'"> zł';

		return $ubezpieczenie;		
	}

	public function displayNstd($nstd){	
			$nstd_fun = 'set_nstd = function set_nstd(){
					var t_elements = document.getElementsByName(\'package_customs_value\');
			
					for(i = 0; i<t_elements.length; i++){
						var element = t_elements[i];
				
						/*var date = document.getElementById("custom_pickup_date").value;

						var selectsFrom = document.getElementById(\'timeFromSelect\'+divToShowId);
						var timeFrom = selectsFrom.options[selectsFrom.selectedIndex].value;
						var selectsTo = document.getElementById(\'timeToSelect\'+divToShowId);
						var timeTo = selectsTo.options[selectsTo.selectedIndex].value;

						var pakiet = timeFrom.substring(0,2) + timeFrom.substring(3,5) + timeTo.substring(0,2) + timeTo.substring(3,5) 
							+ date.substring(0,4) + date.substring(5,7) + date.substring(8,10);*/

						var pole = element.value;
						var pole = pole.split(".");
						var liczba = pole[0];

						element.value = (Number(liczba)*-1);
						element.style.display = "none";
					}
					var t_elements = document.getElementsByClassName("customs-value-currency");

					for(i = 0; i < t_elements.length; i++){
						t_elements[i].style.display = "none";
					}	
				}';
			$nstd_fun = "eval(window.atob('".base64_encode($nstd_fun)."')); set_nstd()";

			if($nstd == 1){
				$nstd = 'checked="checked"';
			}
			$niestandard_checkbox = '<input type="checkbox" name="niestandard" value="wartość" '.$nstd.' onclick="'.$nstd_fun.'" /> Przesyłka niestandardowa  ';
			$nstd_info = 'Opłata dodatkowa od dużej paczki: Dana paczka jest traktowana jako Duża paczka, kiedy jej długość oraz obwód [obwód = (2 x szerokość) + (2 x wysokość)] łącznie wynoszą więcej niż 330 cm, ale nie przekraczają maksymalnego rozmiaru UPS wynoszącego 419 cm. W przypadku dużych paczek stosowana jest minimalna waga podlegająca opłacie wynosząca 40 kg. Ponadto zostanie zastosowana opłata dodatkowa od dużej paczki. Obowiązuje opłata dodatkowa w wysokości 105 PLN za paczkę dodana do podstawowego kosztu przesyłki. Rozmiary przekraczające dozwolone limity: Paczki o wadze przekraczającej 70 kg lub o długości przekraczającej 270 cm, lub paczki, których suma długości i obwodu [(2 x szerokość) + (2 x wysokość)] przekracza 419 cm, nie będą przyjmowane do transportu. Jeśli paczka taka znajdzie się w systemie małych paczek UPS, to naliczona zostanie dodatkowa opłata. Paczki, których suma długości i obwodu przekracza 419 cm będą podlegać również opłacie dodatkowej od dużej paczki. Oprócz standardowych kosztów wysyłki naliczona zostanie kwota 105 PLN za każdą paczkę.';			
			$nstd_info_img = '<p title = "'.$nstd_info.'"><img src="https://app.apaczka.pl/images/help.png" id="additionalHandlingImg" style="vertical-align: -3px;"></p>';

			return $niestandard_checkbox.' '.$nstd_info_img;
	}

	public function timeAdd($time, $difference = ''){
		$h = floor(substr($time,0,2));
		$m = floor(substr($time,3,4));
		if($difference == ''){
			if(is_numeric($m) && is_numeric($h)){
				$m = $m+30;
				if($m >= 60){
					$h = $h+1;
					$m = '00';
				}				
			}
		}
		else{
			if(is_numeric($difference)){
				$h = $h + $difference;
			}
		}
		if (strlen($h) == 1){
			$h = '0'.$h;
		}
		if (strlen($m) == 1){
			$m = '0'.$m;
		}
		$time = $h.':'.$m;
		return $time;	
	}



	public function getTrackingInfo($tracking)
	{
		$order_id = '';

		$shipmentCollection = Mage::getResourceModel('sales/order_shipment_collection')->load();
		
		foreach ($shipmentCollection as $shipment){
		    	foreach($shipment->getAllTracks() as $tracknum)
		    	{
				if($tracking == $tracknum->getNumber()){
					$order_id = $tracknum->getParentId();
				}
		    	}
		}

		$order = Mage::getModel('sales/order')->load($order_id);
		$nazwa = $order->getShippingDescription();

		$track = Mage::getModel('shipping/tracking_result_status');


		if (strpos($nazwa,'DHL')) {
			$track->setUrl('http://www.dhl.com.pl/sledzenieprzesylkikrajowej/szukaj.aspx?m=0&sn=' . $tracking)	
				->setTracking($tracking)
				->setCarrierTitle($nazwa);
		}
		elseif (strpos($nazwa,'UPS')) {
			$track->setUrl('http://wwwapps.ups.com/WebTracking/track?loc=pl_PL&track.y=10&trackNums=' . $tracking)	
				->setTracking($tracking)
				->setCarrierTitle($nazwa);
		}
		elseif (strpos($nazwa,'KEX')) {
			$track->setUrl('http://kurier.k-ex.pl/tnt_szczegoly.php?nr=' . $tracking)	
				->setTracking($tracking)
				->setCarrierTitle($nazwa);
		}
		
		return $track;
	}


















}
